# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from links.v1 import links_pb2 as links_dot_v1_dot_links__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in links/v1/links_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class LinkServiceStub(object):
    """LinkService handles smart link management
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListLinks = channel.unary_unary(
                '/links.v1.LinkService/ListLinks',
                request_serializer=links_dot_v1_dot_links__pb2.ListLinksRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.ListLinksResponse.FromString,
                _registered_method=True)
        self.CreateLink = channel.unary_unary(
                '/links.v1.LinkService/CreateLink',
                request_serializer=links_dot_v1_dot_links__pb2.CreateLinkRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.Link.FromString,
                _registered_method=True)
        self.GetLink = channel.unary_unary(
                '/links.v1.LinkService/GetLink',
                request_serializer=links_dot_v1_dot_links__pb2.GetLinkRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.Link.FromString,
                _registered_method=True)
        self.UpdateLink = channel.unary_unary(
                '/links.v1.LinkService/UpdateLink',
                request_serializer=links_dot_v1_dot_links__pb2.UpdateLinkRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.Link.FromString,
                _registered_method=True)
        self.DeleteLink = channel.unary_unary(
                '/links.v1.LinkService/DeleteLink',
                request_serializer=links_dot_v1_dot_links__pb2.DeleteLinkRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.DeleteLinkResponse.FromString,
                _registered_method=True)
        self.CheckSlug = channel.unary_unary(
                '/links.v1.LinkService/CheckSlug',
                request_serializer=links_dot_v1_dot_links__pb2.CheckSlugRequest.SerializeToString,
                response_deserializer=links_dot_v1_dot_links__pb2.CheckSlugResponse.FromString,
                _registered_method=True)


class LinkServiceServicer(object):
    """LinkService handles smart link management
    """

    def ListLinks(self, request, context):
        """List all links for the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateLink(self, request, context):
        """Create a new smart link
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLink(self, request, context):
        """Get a specific link by ID
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLink(self, request, context):
        """Update an existing link
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLink(self, request, context):
        """Delete a link
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckSlug(self, request, context):
        """Check if a slug is available
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LinkServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLinks,
                    request_deserializer=links_dot_v1_dot_links__pb2.ListLinksRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.ListLinksResponse.SerializeToString,
            ),
            'CreateLink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLink,
                    request_deserializer=links_dot_v1_dot_links__pb2.CreateLinkRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.Link.SerializeToString,
            ),
            'GetLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLink,
                    request_deserializer=links_dot_v1_dot_links__pb2.GetLinkRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.Link.SerializeToString,
            ),
            'UpdateLink': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLink,
                    request_deserializer=links_dot_v1_dot_links__pb2.UpdateLinkRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.Link.SerializeToString,
            ),
            'DeleteLink': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLink,
                    request_deserializer=links_dot_v1_dot_links__pb2.DeleteLinkRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.DeleteLinkResponse.SerializeToString,
            ),
            'CheckSlug': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckSlug,
                    request_deserializer=links_dot_v1_dot_links__pb2.CheckSlugRequest.FromString,
                    response_serializer=links_dot_v1_dot_links__pb2.CheckSlugResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'links.v1.LinkService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('links.v1.LinkService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class LinkService(object):
    """LinkService handles smart link management
    """

    @staticmethod
    def ListLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/ListLinks',
            links_dot_v1_dot_links__pb2.ListLinksRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.ListLinksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/CreateLink',
            links_dot_v1_dot_links__pb2.CreateLinkRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.Link.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/GetLink',
            links_dot_v1_dot_links__pb2.GetLinkRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.Link.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/UpdateLink',
            links_dot_v1_dot_links__pb2.UpdateLinkRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.Link.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/DeleteLink',
            links_dot_v1_dot_links__pb2.DeleteLinkRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.DeleteLinkResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CheckSlug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/links.v1.LinkService/CheckSlug',
            links_dot_v1_dot_links__pb2.CheckSlugRequest.SerializeToString,
            links_dot_v1_dot_links__pb2.CheckSlugResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from analytics.v1 import analytics_pb2 as analytics_dot_v1_dot_analytics__pb2

GRPC_GENERATED_VERSION = '1.78.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in analytics/v1/analytics_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class AnalyticsServiceStub(object):
    """AnalyticsService handles link analytics
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetStats = channel.unary_unary(
                '/analytics.v1.AnalyticsService/GetStats',
                request_serializer=analytics_dot_v1_dot_analytics__pb2.GetStatsRequest.SerializeToString,
                response_deserializer=analytics_dot_v1_dot_analytics__pb2.GetStatsResponse.FromString,
                _registered_method=True)
        self.GetTimeseries = channel.unary_unary(
                '/analytics.v1.AnalyticsService/GetTimeseries',
                request_serializer=analytics_dot_v1_dot_analytics__pb2.GetTimeseriesRequest.SerializeToString,
                response_deserializer=analytics_dot_v1_dot_analytics__pb2.GetTimeseriesResponse.FromString,
                _registered_method=True)
        self.GetPlatforms = channel.unary_unary(
                '/analytics.v1.AnalyticsService/GetPlatforms',
                request_serializer=analytics_dot_v1_dot_analytics__pb2.GetPlatformsRequest.SerializeToString,
                response_deserializer=analytics_dot_v1_dot_analytics__pb2.GetPlatformsResponse.FromString,
                _registered_method=True)
        self.GetCountries = channel.unary_unary(
                '/analytics.v1.AnalyticsService/GetCountries',
                request_serializer=analytics_dot_v1_dot_analytics__pb2.GetCountriesRequest.SerializeToString,
                response_deserializer=analytics_dot_v1_dot_analytics__pb2.GetCountriesResponse.FromString,
                _registered_method=True)
        self.GetReferrers = channel.unary_unary(
                '/analytics.v1.AnalyticsService/GetReferrers',
                request_serializer=analytics_dot_v1_dot_analytics__pb2.GetReferrersRequest.SerializeToString,
                response_deserializer=analytics_dot_v1_dot_analytics__pb2.GetReferrersResponse.FromString,
                _registered_method=True)


class AnalyticsServiceServicer(object):
    """AnalyticsService handles link analytics
    """

    def GetStats(self, request, context):
        """Get overview statistics for a link
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTimeseries(self, request, context):
        """Get click data over time
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPlatforms(self, request, context):
        """Get breakdown by platform
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCountries(self, request, context):
        """Get breakdown by country
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferrers(self, request, context):
        """Get top referrers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AnalyticsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetStats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStats,
                    request_deserializer=analytics_dot_v1_dot_analytics__pb2.GetStatsRequest.FromString,
                    response_serializer=analytics_dot_v1_dot_analytics__pb2.GetStatsResponse.SerializeToString,
            ),
            'GetTimeseries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTimeseries,
                    request_deserializer=analytics_dot_v1_dot_analytics__pb2.GetTimeseriesRequest.FromString,
                    response_serializer=analytics_dot_v1_dot_analytics__pb2.GetTimeseriesResponse.SerializeToString,
            ),
            'GetPlatforms': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPlatforms,
                    request_deserializer=analytics_dot_v1_dot_analytics__pb2.GetPlatformsRequest.FromString,
                    response_serializer=analytics_dot_v1_dot_analytics__pb2.GetPlatformsResponse.SerializeToString,
            ),
            'GetCountries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCountries,
                    request_deserializer=analytics_dot_v1_dot_analytics__pb2.GetCountriesRequest.FromString,
                    response_serializer=analytics_dot_v1_dot_analytics__pb2.GetCountriesResponse.SerializeToString,
            ),
            'GetReferrers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferrers,
                    request_deserializer=analytics_dot_v1_dot_analytics__pb2.GetReferrersRequest.FromString,
                    response_serializer=analytics_dot_v1_dot_analytics__pb2.GetReferrersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'analytics.v1.AnalyticsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('analytics.v1.AnalyticsService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AnalyticsService(object):
    """AnalyticsService handles link analytics
    """

    @staticmethod
    def GetStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analytics.v1.AnalyticsService/GetStats',
            analytics_dot_v1_dot_analytics__pb2.GetStatsRequest.SerializeToString,
            analytics_dot_v1_dot_analytics__pb2.GetStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTimeseries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analytics.v1.AnalyticsService/GetTimeseries',
            analytics_dot_v1_dot_analytics__pb2.GetTimeseriesRequest.SerializeToString,
            analytics_dot_v1_dot_analytics__pb2.GetTimeseriesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPlatforms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analytics.v1.AnalyticsService/GetPlatforms',
            analytics_dot_v1_dot_analytics__pb2.GetPlatformsRequest.SerializeToString,
            analytics_dot_v1_dot_analytics__pb2.GetPlatformsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCountries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analytics.v1.AnalyticsService/GetCountries',
            analytics_dot_v1_dot_analytics__pb2.GetCountriesRequest.SerializeToString,
            analytics_dot_v1_dot_analytics__pb2.GetCountriesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReferrers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/analytics.v1.AnalyticsService/GetReferrers',
            analytics_dot_v1_dot_analytics__pb2.GetReferrersRequest.SerializeToString,
            analytics_dot_v1_dot_analytics__pb2.GetReferrersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
Go2 SDK - Official Python SDK for the Go2 gRPC API.

Example usage:
    from go2_sdk import Go2Client

    with Go2Client(api_key="go2_your_key") as client:
        # Smart Links
        links = client.links.list()
        link = client.links.create(
            slug="myapp",
            ios_url="https://apps.apple.com/...",
            android_url="https://play.google.com/...",
        )

        # Analytics
        stats = client.analytics.get_stats(link_id=link.id)

        # Custom Domains
        domains = client.domains.list()

        # QR Codes
        qr = client.qr.generate(link_id=link.id)

        # Integrations
        integrations = client.integrations.list()

        # Campaigns
        campaigns = client.campaigns.list()
"""

from go2_sdk.client import (
    Go2Client,
    IntegrationsService,
    LinksService,
    AnalyticsService,
    DomainsService,
    QRService,
    CampaignsService,
)
from go2_sdk.errors import (
    Go2Error,
    AuthenticationError,
    NotFoundError,
    PermissionDeniedError,
    ValidationError,
    RateLimitError,
)

__version__ = "1.2.4"
__all__ = [
    "Go2Client",
    "IntegrationsService",
    "LinksService",
    "AnalyticsService",
    "DomainsService",
    "QRService",
    "CampaignsService",
    "Go2Error",
    "AuthenticationError",
    "NotFoundError",
    "PermissionDeniedError",
    "ValidationError",
    "RateLimitError",
]

# Re-export generated types when available
try:
    from go2_sdk.gen.integrations.v1 import integrations_pb2
    from go2_sdk.gen.links.v1 import links_pb2
    from go2_sdk.gen.campaigns.v1 import campaigns_pb2

    IntegrationType = integrations_pb2.IntegrationType
    IntegrationConfig = integrations_pb2.IntegrationConfig
    Integration = integrations_pb2.Integration
    Link = links_pb2.Link
    Campaign = campaigns_pb2.Campaign

    __all__.extend([
        "IntegrationType",
        "IntegrationConfig",
        "Integration",
        "Link",
        "Campaign",
    ])
except ImportError:
    pass  # Generated code not yet available



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetStatsRequest(_message.Message):
    __slots__ = ("link_id", "period")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    period: str
    def __init__(self, link_id: _Optional[str] = ..., period: _Optional[str] = ...) -> None: ...

class GetStatsResponse(_message.Message):
    __slots__ = ("total_clicks", "unique_clicks", "ios_clicks", "android_clicks", "web_clicks", "other_clicks", "top_countries", "top_referrers")
    TOTAL_CLICKS_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_CLICKS_FIELD_NUMBER: _ClassVar[int]
    IOS_CLICKS_FIELD_NUMBER: _ClassVar[int]
    ANDROID_CLICKS_FIELD_NUMBER: _ClassVar[int]
    WEB_CLICKS_FIELD_NUMBER: _ClassVar[int]
    OTHER_CLICKS_FIELD_NUMBER: _ClassVar[int]
    TOP_COUNTRIES_FIELD_NUMBER: _ClassVar[int]
    TOP_REFERRERS_FIELD_NUMBER: _ClassVar[int]
    total_clicks: int
    unique_clicks: int
    ios_clicks: int
    android_clicks: int
    web_clicks: int
    other_clicks: int
    top_countries: _containers.RepeatedCompositeFieldContainer[CountryStats]
    top_referrers: _containers.RepeatedCompositeFieldContainer[ReferrerStats]
    def __init__(self, total_clicks: _Optional[int] = ..., unique_clicks: _Optional[int] = ..., ios_clicks: _Optional[int] = ..., android_clicks: _Optional[int] = ..., web_clicks: _Optional[int] = ..., other_clicks: _Optional[int] = ..., top_countries: _Optional[_Iterable[_Union[CountryStats, _Mapping]]] = ..., top_referrers: _Optional[_Iterable[_Union[ReferrerStats, _Mapping]]] = ...) -> None: ...

class GetTimeseriesRequest(_message.Message):
    __slots__ = ("link_id", "period")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    period: str
    def __init__(self, link_id: _Optional[str] = ..., period: _Optional[str] = ...) -> None: ...

class GetTimeseriesResponse(_message.Message):
    __slots__ = ("points",)
    POINTS_FIELD_NUMBER: _ClassVar[int]
    points: _containers.RepeatedCompositeFieldContainer[TimeseriesPoint]
    def __init__(self, points: _Optional[_Iterable[_Union[TimeseriesPoint, _Mapping]]] = ...) -> None: ...

class TimeseriesPoint(_message.Message):
    __slots__ = ("date", "clicks", "unique_clicks")
    DATE_FIELD_NUMBER: _ClassVar[int]
    CLICKS_FIELD_NUMBER: _ClassVar[int]
    UNIQUE_CLICKS_FIELD_NUMBER: _ClassVar[int]
    date: str
    clicks: int
    unique_clicks: int
    def __init__(self, date: _Optional[str] = ..., clicks: _Optional[int] = ..., unique_clicks: _Optional[int] = ...) -> None: ...

class GetPlatformsRequest(_message.Message):
    __slots__ = ("link_id", "period")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    period: str
    def __init__(self, link_id: _Optional[str] = ..., period: _Optional[str] = ...) -> None: ...

class GetPlatformsResponse(_message.Message):
    __slots__ = ("platforms",)
    PLATFORMS_FIELD_NUMBER: _ClassVar[int]
    platforms: _containers.RepeatedCompositeFieldContainer[PlatformStats]
    def __init__(self, platforms: _Optional[_Iterable[_Union[PlatformStats, _Mapping]]] = ...) -> None: ...

class PlatformStats(_message.Message):
    __slots__ = ("platform", "clicks", "percentage")
    PLATFORM_FIELD_NUMBER: _ClassVar[int]
    CLICKS_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    platform: str
    clicks: int
    percentage: float
    def __init__(self, platform: _Optional[str] = ..., clicks: _Optional[int] = ..., percentage: _Optional[float] = ...) -> None: ...

class GetCountriesRequest(_message.Message):
    __slots__ = ("link_id", "period", "limit")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    period: str
    limit: int
    def __init__(self, link_id: _Optional[str] = ..., period: _Optional[str] = ..., limit: _Optional[int] = ...) -> None: ...

class GetCountriesResponse(_message.Message):
    __slots__ = ("countries",)
    COUNTRIES_FIELD_NUMBER: _ClassVar[int]
    countries: _containers.RepeatedCompositeFieldContainer[CountryStats]
    def __init__(self, countries: _Optional[_Iterable[_Union[CountryStats, _Mapping]]] = ...) -> None: ...

class CountryStats(_message.Message):
    __slots__ = ("country_code", "country_name", "clicks", "percentage")
    COUNTRY_CODE_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_NAME_FIELD_NUMBER: _ClassVar[int]
    CLICKS_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    country_code: str
    country_name: str
    clicks: int
    percentage: float
    def __init__(self, country_code: _Optional[str] = ..., country_name: _Optional[str] = ..., clicks: _Optional[int] = ..., percentage: _Optional[float] = ...) -> None: ...

class GetReferrersRequest(_message.Message):
    __slots__ = ("link_id", "period", "limit")
    LINK_ID_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    link_id: str
    period: str
    limit: int
    def __init__(self, link_id: _Optional[str] = ..., period: _Optional[str] = ..., limit: _Optional[int] = ...) -> None: ...

class GetReferrersResponse(_message.Message):
    __slots__ = ("referrers",)
    REFERRERS_FIELD_NUMBER: _ClassVar[int]
    referrers: _containers.RepeatedCompositeFieldContainer[ReferrerStats]
    def __init__(self, referrers: _Optional[_Iterable[_Union[ReferrerStats, _Mapping]]] = ...) -> None: ...

class ReferrerStats(_message.Message):
    __slots__ = ("referrer", "clicks", "percentage")
    REFERRER_FIELD_NUMBER: _ClassVar[int]
    CLICKS_FIELD_NUMBER: _ClassVar[int]
    PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
    referrer: str
    clicks: int
    percentage: float
    def __init__(self, referrer: _Optional[str] = ..., clicks: _Optional[int] = ..., percentage: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: campaigns/v1/campaigns.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'campaigns/v1/campaigns.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63\x61mpaigns/v1/campaigns.proto\x12\x0c\x63\x61mpaigns.v1\"\xaf\x02\n\x08\x43\x61mpaign\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x05 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x06 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x07 \x01(\t\x12\x18\n\x10total_recipients\x18\x08 \x01(\x05\x12\x14\n\x0ctotal_clicks\x18\t \x01(\x03\x12\x15\n\runique_clicks\x18\n \x01(\x05\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x12\n\nupdated_at\x18\r \x01(\t\x12\x12\n\nexpires_at\x18\x0e \x01(\t\"\xc9\x03\n\x0c\x43\x61mpaignLink\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61mpaign_id\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x14\n\x0crecipient_id\x18\x04 \x01(\t\x12\x16\n\x0erecipient_name\x18\x05 \x01(\t\x12M\n\x12recipient_metadata\x18\x06 \x03(\x0b\x32\x31.campaigns.v1.CampaignLink.RecipientMetadataEntry\x12\x0f\n\x07\x63licked\x18\x07 \x01(\x08\x12\x18\n\x10\x66irst_clicked_at\x18\x08 \x01(\t\x12\x17\n\x0flast_clicked_at\x18\t \x01(\t\x12\x13\n\x0b\x63lick_count\x18\n \x01(\x05\x12\x1c\n\x14\x66irst_click_platform\x18\x0b \x01(\t\x12\x1b\n\x13\x66irst_click_country\x18\x0c \x01(\t\x12\x18\n\x10\x66irst_click_city\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x0e \x01(\t\x12\x11\n\tshort_url\x18\x0f \x01(\t\x1a\x38\n\x16RecipientMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\tRecipient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x37\n\x08metadata\x18\x03 \x03(\x0b\x32%.campaigns.v1.Recipient.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x14ListCampaignsRequest\x12\r\n\x05limit\x18\x01 \x01(\x05\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x0e\n\x06search\x18\x04 \x01(\t\"Q\n\x15ListCampaignsResponse\x12)\n\tcampaigns\x18\x01 \x03(\x0b\x32\x16.campaigns.v1.Campaign\x12\r\n\x05total\x18\x02 \x01(\x05\"\xa0\x01\n\x15\x43reateCampaignRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x03 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x04 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x05 \x01(\t\x12\x12\n\nexpires_at\x18\x06 \x01(\t\" \n\x12GetCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\xbc\x01\n\x15UpdateCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65stination_url\x18\x04 \x01(\t\x12\x19\n\x11pass_recipient_id\x18\x05 \x01(\x08\x12\x1c\n\x14recipient_param_name\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\x12\x12\n\nexpires_at\x18\x08 \x01(\t\"#\n\x15\x44\x65leteCampaignRequest\x12\n\n\x02id\x18\x01 \x01(\t\")\n\x16\x44\x65leteCampaignResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"X\n\x14GenerateLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12+\n\nrecipients\x18\x02 \x03(\x0b\x32\x17.campaigns.v1.Recipient\"u\n\x15GenerateLinksResponse\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x15\n\rlinks_created\x18\x02 \x01(\x05\x12\x30\n\x0csample_links\x18\x03 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink\"t\n\x18ListCampaignLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x0e\n\x06offset\x18\x03 \x01(\x05\x12\x14\n\x0c\x63licked_only\x18\x04 \x01(\x08\x12\x0e\n\x06search\x18\x05 \x01(\t\"U\n\x19ListCampaignLinksResponse\x12)\n\x05links\x18\x01 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink\x12\r\n\x05total\x18\x02 \x01(\x05\".\n\x17GetCampaignStatsRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\"\x85\x04\n\rCampaignStats\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x18\n\x10total_recipients\x18\x02 \x01(\x05\x12\x14\n\x0ctotal_clicks\x18\x03 \x01(\x03\x12\x15\n\runique_clicks\x18\x04 \x01(\x05\x12\x12\n\nclick_rate\x18\x05 \x01(\x01\x12M\n\x12\x63licks_by_platform\x18\x06 \x03(\x0b\x32\x31.campaigns.v1.CampaignStats.ClicksByPlatformEntry\x12K\n\x11\x63licks_by_country\x18\x07 \x03(\x0b\x32\x30.campaigns.v1.CampaignStats.ClicksByCountryEntry\x12\x43\n\rclicks_by_day\x18\x08 \x03(\x0b\x32,.campaigns.v1.CampaignStats.ClicksByDayEntry\x1a\x37\n\x15\x43licksByPlatformEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x36\n\x14\x43licksByCountryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x32\n\x10\x43licksByDayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"9\n\x12\x45xportLinksRequest\x12\x13\n\x0b\x63\x61mpaign_id\x18\x01 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x02 \x01(\t\"@\n\x13\x45xportLinksResponse\x12)\n\x05links\x18\x01 \x03(\x0b\x32\x1a.campaigns.v1.CampaignLink2\x9b\x06\n\x0f\x43\x61mpaignService\x12X\n\rListCampaigns\x12\".campaigns.v1.ListCampaignsRequest\x1a#.campaigns.v1.ListCampaignsResponse\x12M\n\x0e\x43reateCampaign\x12#.campaigns.v1.CreateCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12G\n\x0bGetCampaign\x12 .campaigns.v1.GetCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12M\n\x0eUpdateCampaign\x12#.campaigns.v1.UpdateCampaignRequest\x1a\x16.campaigns.v1.Campaign\x12[\n\x0e\x44\x65leteCampaign\x12#.campaigns.v1.DeleteCampaignRequest\x1a$.campaigns.v1.DeleteCampaignResponse\x12X\n\rGenerateLinks\x12\".campaigns.v1.GenerateLinksRequest\x1a#.campaigns.v1.GenerateLinksResponse\x12\x64\n\x11ListCampaignLinks\x12&.campaigns.v1.ListCampaignLinksRequest\x1a\'.campaigns.v1.ListCampaignLinksResponse\x12V\n\x10GetCampaignStats\x12%.campaigns.v1.GetCampaignStatsRequest\x1a\x1b.campaigns.v1.CampaignStats\x12R\n\x0b\x45xportLinks\x12 .campaigns.v1.ExportLinksRequest\x1a!.campaigns.v1.ExportLinksResponseB9Z7github.com/gosms-ge/go2-sdk/go/campaigns/v1;campaignsv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'campaigns.v1.campaigns_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/gosms-ge/go2-sdk/go/campaigns/v1;campaignsv1'
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._loaded_options = None
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_RECIPIENT_METADATAENTRY']._loaded_options = None
  _globals['_RECIPIENT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._loaded_options = None
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_options = b'8\001'
  _globals['_CAMPAIGN']._serialized_start=47
  _globals['_CAMPAIGN']._serialized_end=350
  _globals['_CAMPAIGNLINK']._serialized_start=353
  _globals['_CAMPAIGNLINK']._serialized_end=810
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_start=754
  _globals['_CAMPAIGNLINK_RECIPIENTMETADATAENTRY']._serialized_end=810
  _globals['_RECIPIENT']._serialized_start=813
  _globals['_RECIPIENT']._serialized_end=956
  _globals['_RECIPIENT_METADATAENTRY']._serialized_start=909
  _globals['_RECIPIENT_METADATAENTRY']._serialized_end=956
  _globals['_LISTCAMPAIGNSREQUEST']._serialized_start=958
  _globals['_LISTCAMPAIGNSREQUEST']._serialized_end=1043
  _globals['_LISTCAMPAIGNSRESPONSE']._serialized_start=1045
  _globals['_LISTCAMPAIGNSRESPONSE']._serialized_end=1126
  _globals['_CREATECAMPAIGNREQUEST']._serialized_start=1129
  _globals['_CREATECAMPAIGNREQUEST']._serialized_end=1289
  _globals['_GETCAMPAIGNREQUEST']._serialized_start=1291
  _globals['_GETCAMPAIGNREQUEST']._serialized_end=1323
  _globals['_UPDATECAMPAIGNREQUEST']._serialized_start=1326
  _globals['_UPDATECAMPAIGNREQUEST']._serialized_end=1514
  _globals['_DELETECAMPAIGNREQUEST']._serialized_start=1516
  _globals['_DELETECAMPAIGNREQUEST']._serialized_end=1551
  _globals['_DELETECAMPAIGNRESPONSE']._serialized_start=1553
  _globals['_DELETECAMPAIGNRESPONSE']._serialized_end=1594
  _globals['_GENERATELINKSREQUEST']._serialized_start=1596
  _globals['_GENERATELINKSREQUEST']._serialized_end=1684
  _globals['_GENERATELINKSRESPONSE']._serialized_start=1686
  _globals['_GENERATELINKSRESPONSE']._serialized_end=1803
  _globals['_LISTCAMPAIGNLINKSREQUEST']._serialized_start=1805
  _globals['_LISTCAMPAIGNLINKSREQUEST']._serialized_end=1921
  _globals['_LISTCAMPAIGNLINKSRESPONSE']._serialized_start=1923
  _globals['_LISTCAMPAIGNLINKSRESPONSE']._serialized_end=2008
  _globals['_GETCAMPAIGNSTATSREQUEST']._serialized_start=2010
  _globals['_GETCAMPAIGNSTATSREQUEST']._serialized_end=2056
  _globals['_CAMPAIGNSTATS']._serialized_start=2059
  _globals['_CAMPAIGNSTATS']._serialized_end=2576
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_start=2413
  _globals['_CAMPAIGNSTATS_CLICKSBYPLATFORMENTRY']._serialized_end=2468
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_start=2470
  _globals['_CAMPAIGNSTATS_CLICKSBYCOUNTRYENTRY']._serialized_end=2524
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_start=2526
  _globals['_CAMPAIGNSTATS_CLICKSBYDAYENTRY']._serialized_end=2576
  _globals['_EXPORTLINKSREQUEST']._serialized_start=2578
  _globals['_EXPORTLINKSREQUEST']._serialized_end=2635
  _globals['_EXPORTLINKSRESPONSE']._serialized_start=2637
  _globals['_EXPORTLINKSRESPONSE']._serialized_end=2701
  _globals['_CAMPAIGNSERVICE']._serialized_start=2704
  _globals['_CAMPAIGNSERVICE']._serialized_end=3499
# @@protoc_insertion_point(module_scope)
